@@ -7,6 +7,8 @@ extern crate tokio;
 extern crate url;
 extern crate hashbrown;
 extern crate log;
+#[macro_use]
+extern crate lazy_static;
 
 /// Configuration structure for `Website`
 pub mod configuration;
@@ -19,7 +21,7 @@ pub mod website;
 
 #[cfg(feature = "regex")]
 /// Black list checking url exist with Regex
-mod black_list {
+pub mod black_list {
     use regex::Regex;
     /// check if link exist in blacklists with regex
     pub fn contains(blacklist_url: &Vec<String>, link: &String) -> bool {
@@ -36,7 +38,7 @@ mod black_list {
 
 #[cfg(not(feature = "regex"))]
 /// Black list checking url exist
-mod black_list {
+pub mod black_list {
     /// check if link exist in blacklists
     pub fn contains(blacklist_url: &Vec<String>, link: &String) -> bool {
         blacklist_url.contains(&link)
